@@ -79,8 +79,7 @@ check_model.default <- function(x, dot_size = 2, line_size = .8, panel = TRUE, c
   dat$NORM <- .diag_norm(model)
   dat$NCV <- .diag_ncv(model)
   dat$HOMOGENEITY <- .diag_homogeneity(model)
-  dat$OUTLIERS <- check_outliers(model)
-  if (!is.null(dat$OUTLIERS)) class(dat$OUTLIERS) <- "data.frame"
+  dat$OUTLIERS <- check_outliers(model, method = "cook")
 
   dat <- .compact_list(dat)
   class(dat) <- c("check_model", "see_check_model")
@@ -97,8 +96,7 @@ check_model.default <- function(x, dot_size = 2, line_size = .8, panel = TRUE, c
   dat$QQ <- .diag_qq(model)
   dat$HOMOGENEITY <- .diag_homogeneity(model)
   dat$REQQ <- .diag_reqq(model, level = .95, model_info = model_info)
-  dat$OUTLIERS <- check_outliers(model)
-  if (!is.null(dat$OUTLIERS)) class(dat$OUTLIERS) <- "data.frame"
+  dat$OUTLIERS <- check_outliers(model, method = "cook")
 
   dat <- .compact_list(dat)
   class(dat) <- c("check_model", "see_check_model")
