@@ -14,16 +14,13 @@ if (require("testthat") && require("performance") && require("survival")) {
   })
 
   test_that("model_performance", {
-    expect_equal(
-      model_performance(m1),
-      data.frame(
-        AIC = 1457.19458886438,
-        BIC = 1469.5695896676,
-        R2_Nagelkerke = 0.162679484267414,
-        RMSE = 0.882014942836432
-      ),
-      tolerance = 1e-4
-    )
+    perf <- model_performance(m1)
+
+    expect_equal(perf$AIC, 1457.19458886438, tolerance = 1e-4)
+    expect_equal(perf$BIC, 1469.5695896676, tolerance = 1e-4)
+    expect_equal(perf$R2_Nagelkerke, 0.162679484267414, tolerance = 1e-4)
+    expect_equal(perf$RMSE, 0.882014942836432, tolerance = 1e-4)
+
   })
 
   test_that("r2", {
